BackgroundDrawable class abstract

Abstract class to define a drawable object to be used as a background.

Inheritance
Implementers

Constructors

BackgroundDrawable()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the drawable is hidden or not.
finalinherited
isHidden → bool
no setterinherited
isNotHidden → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Size size) → void
Draws the drawable on the provided canvas of size size.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited