Drawable class abstract

Abstract class to define a drawable object.

Implementers

Constructors

Drawable({bool hidden = false})
Default constructor.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the drawable is hidden or not.
final
isHidden → bool
no setter
isNotHidden → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Size size) → void
Draws the drawable on the provided canvas of size size.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited