ImageBackgroundDrawable class

Drawable to use an image as a background.

Inheritance
Annotations

Constructors

ImageBackgroundDrawable({required Image image})
Creates a ImageBackgroundDrawable to use an image as a background.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the drawable is hidden or not.
finalinherited
image → Image
The image to be used as a background.
final
isHidden → bool
no setterinherited
isNotHidden → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Size size) → void
Draws the image on the provided canvas of size size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited