PainterControllerValue class

The current paint mode, drawables and background values of a FlutterPainter widget.

Annotations

Constructors

PainterControllerValue({required PainterSettings settings, List<Drawable> drawables = const [], BackgroundDrawable? background, ObjectDrawable? selectedObjectDrawable})
Creates a new PainterControllerValue with the provided settings and background.
const

Properties

background → BackgroundDrawable?
The current background drawable of the widget.
final
drawables → List<Drawable>
Getter for the current drawables.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedObjectDrawable → ObjectDrawable?
The currently selected object drawable.
final
settings → PainterSettings
The current paint mode of the widget.
final

Methods

copyWith({PainterSettings? settings, List<Drawable>? drawables, BackgroundDrawable? background = _NoBackgroundPassedBackgroundDrawable.instance, ObjectDrawable? selectedObjectDrawable = _NoObjectPassedBackgroundDrawable.instance}) → PainterControllerValue
Creates a copy of this value but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Checks if two PainterControllerValue objects are equal or not.
override