PathDrawable class abstract

Free-style Drawable (hand scribble).

Inheritance
Implementers

Constructors

PathDrawable({required List<Offset> path, double strokeWidth = 1, bool hidden = false})
Creates a PathDrawable to draw path.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the drawable is hidden or not.
finalinherited
isHidden → bool
no setterinherited
isNotHidden → bool
no setterinherited
paint → Paint
no setter
path → List<Offset>
List of points representing the path to draw.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
The stroke width the path will be drawn with.
final

Methods

copyWith({bool? hidden, List<Offset>? path, double? strokeWidth}) → PathDrawable
Creates a copy of this but with the given fields replaced with the new values.
draw(Canvas canvas, Size size) → void
Draws the free-style path on the provided canvas of size size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited