ShapeFactory<T extends ShapeDrawable> class abstract

An abstract class that defines an object that can create shape drawables.

Implementers

Constructors

ShapeFactory()
Creates an instance of ShapeFactory.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Offset position, [Paint? paint]) → T
Creates the desired shape drawable. Inheriting classes must override this method to create the appropriate ShapeDrawable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited